@@ -69,10 +69,10 @@ class diffmatrix:
         self.matrix = None
         self.E = False
         self.ET = False
-        if len(args) > 0 and args[0] is "E":
+        if len(args) > 0 and isinstance(args[0], str) and args[0] == "E":
             self.E = True
             return
-        if len(args) > 0 and args[0] is "ET":
+        if len(args) > 0 and isinstance(args[0], str) and args[0] == "ET":
             self.E = True
             return
         args = totuple(args)
